@@ -6,30 +6,46 @@ from pynpdc.auth_client import (
     AuthClient as AuthClient,
 )
 
-from pynpdc.dataset_client import (
-    DATASET_LIFE_ENTRYPOINT as DATASET_LIFE_ENTRYPOINT,
-    DATASET_STAGING_ENTRYPOINT as DATASET_STAGING_ENTRYPOINT,
-    DatasetClient as DatasetClient,
+from pynpdc.data_client import (
+    DATA_LIFE_ENTRYPOINT as DATA_LIFE_ENTRYPOINT,
+    DATA_STAGING_ENTRYPOINT as DATA_STAGING_ENTRYPOINT,
+    DataClient as DataClient,
 )
 
+# kept for backwards compatibility
+from pynpdc.data_client import (
+    DATA_LIFE_ENTRYPOINT as DATASET_LIFE_ENTRYPOINT,
+    DATA_STAGING_ENTRYPOINT as DATASET_STAGING_ENTRYPOINT,
+    DataClient as DatasetClient,
+)
+
+
 from pynpdc.models import (
     DEFAULT_CHUNK_SIZE as DEFAULT_CHUNK_SIZE,
-    Account as Account,
     AccessLevel as AccessLevel,
+    Account as Account,
     AccountWithToken as AccountWithToken,
     Attachment as Attachment,
     AttachmentCollection as AttachmentCollection,
-    AuthContainer as AuthContainer,
-    Content as Content,
-    Dataset as Dataset,
-    DatasetCollection as DatasetCollection,
-    DatasetType as DatasetType,
-    Permission as Permission,
-    PermissionCollection as PermissionCollection,
-    Record as Record,
-    RecordCreateDTO as RecordCreateDTO,
     AttachmentCreateDTO as AttachmentCreateDTO,
     AttachmentCreationInfo as AttachmentCreationInfo,
+    AuthContainer as AuthContainer,
+    Dataset as Dataset,
+    DatasetCollection as DatasetCollection,
+    DatasetContent as DatasetContent,
+    DatasetLink as DatasetLink,
+    DatasetOrganisation as DatasetOrganisation,
+    DatasetPerson as DatasetPerson,
+    DatasetTimeframe as DatasetTimeframe,
+    DatasetType as DatasetType,
+    GMCDScienceKeyword as GMCDScienceKeyword,
+    OrganisationRole as OrganisationRole,
+    Permission as Permission,
+    PermissionCollection as PermissionCollection,
+    PersonRole as PersonRole,
+    Record as Record,
+    RecordContent as RecordContent,
+    RecordCreateDTO as RecordCreateDTO,
 )
 
 from pynpdc.exception import (
